Creates and returns a Shiny application for exploring antimicrobial resistance data and machine learning model results.

launchAMRDashboard(results_root = NULL)

Arguments

results_root

File path to the root directory containing amRml model output results. If NULL (default), the application will attempt to use example data bundled with the package, where available.

Value

A Shiny application object

Examples

if (interactive()) {
  app <- launchAMRDashboard()
  shiny::runApp(app)
}